'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));
var PropTypes = _interopDefault(require('prop-types'));
var tokens = require('@thumbtack/thumbprint-tokens');
var styles = _interopDefault(require('./index.module.scss'));

var labelCursor = {
  error: 'pointer',
  disabled: 'default',
  default: 'pointer'
};
var color = {
  error: {
    unchecked: tokens.tpColorRed,
    checked: tokens.tpColorRed,
    indeterminate: tokens.tpColorRed
  },
  disabled: {
    unchecked: tokens.tpColorGray,
    checked: tokens.tpColorGray,
    indeterminate: tokens.tpColorGray
  },
  default: {
    unchecked: 'inherit',
    checked: tokens.tpColorWhite,
    indeterminate: tokens.tpColorWhite
  }
};
var borderColor = {
  error: {
    unchecked: tokens.tpColorRed,
    checked: tokens.tpColorRed,
    indeterminate: tokens.tpColorRed
  },
  disabled: {
    unchecked: tokens.tpColorGray300,
    checked: tokens.tpColorGray300,
    indeterminate: tokens.tpColorGray300
  },
  default: {
    unchecked: tokens.tpColorGray,
    checked: tokens.tpColorBlue,
    indeterminate: tokens.tpColorBlue
  }
};
var backgroundColor = {
  error: {
    unchecked: tokens.tpColorWhite,
    checked: tokens.tpColorWhite,
    indeterminate: tokens.tpColorWhite
  },
  disabled: {
    unchecked: tokens.tpColorGray200,
    checked: tokens.tpColorGray200,
    indeterminate: tokens.tpColorGray200
  },
  default: {
    unchecked: tokens.tpColorWhite,
    checked: tokens.tpColorBlue,
    indeterminate: tokens.tpColorBlue
  }
};
var textColor = {
  error: tokens.tpColorRed,
  disabled: 'inherit',
  default: 'inherit'
};

var getCheckedState = function getCheckedState(_ref) {
  var isChecked = _ref.isChecked,
      isIndeterminate = _ref.isIndeterminate;

  if (isChecked) {
    return 'checked';
  }

  if (isIndeterminate) {
    return 'indeterminate';
  }

  return 'unchecked';
};

var getFunctionalState = function getFunctionalState(_ref2) {
  var isDisabled = _ref2.isDisabled,
      hasError = _ref2.hasError;

  if (isDisabled) {
    return 'disabled';
  }

  if (hasError) {
    return 'error';
  }

  return 'default';
};

var Checkbox = function Checkbox(_ref3) {
  var children = _ref3.children,
      dataTest = _ref3.dataTest,
      hasError = _ref3.hasError,
      id = _ref3.id,
      isChecked = _ref3.isChecked,
      isDisabled = _ref3.isDisabled,
      isIndeterminate = _ref3.isIndeterminate,
      labelPadding = _ref3.labelPadding,
      name = _ref3.name,
      _onChange = _ref3.onChange;
  var functionalState = getFunctionalState({
    isDisabled: isDisabled,
    hasError: hasError
  });
  var checkedState = getCheckedState({
    isChecked: isChecked,
    isIndeterminate: isIndeterminate
  });
  return (// eslint-disable-next-line jsx-a11y/label-has-associated-control, jsx-a11y/label-has-for
    React.createElement("label", {
      className: styles.root,
      style: {
        cursor: labelCursor[functionalState],
        padding: labelPadding
      }
    }, React.createElement("input", {
      className: styles.input,
      "aria-checked": isIndeterminate ? 'mixed' : isChecked,
      "data-test": dataTest,
      type: "checkbox",
      name: name,
      checked: isChecked,
      onChange: function onChange(e) {
        return _onChange(e.target.checked, id);
      },
      disabled: isDisabled
    }), React.createElement("div", {
      className: styles.checkboxImage,
      style: {
        color: color[functionalState][checkedState],
        backgroundColor: backgroundColor[functionalState][checkedState],
        borderColor: borderColor[functionalState][checkedState]
      }
    }, isChecked && !isIndeterminate && React.createElement("svg", {
      xmlns: "http://www.w3.org/2000/svg",
      fill: "currentColor",
      width: "18",
      height: "18",
      viewBox: "0 0 18 18",
      "data-thumbprint-id": "contentactions-check--small"
    }, React.createElement("path", {
      fillRule: "evenodd",
      d: "M14.5810763,3.19812449 C14.132085,2.85681117 13.5060971,2.96739243 13.1851033,3.44586905 L8.01720309,11.1408364 L4.52827048,8.83245251 C4.05827956,8.52197434 3.44229146,8.67402358 3.1502971,9.17270255 C2.85930272,9.67138151 3.00329993,10.3274261 3.47229088,10.6379043 L8.55419272,14 L14.8130718,4.68246529 C15.1350656,4.20398867 15.0300676,3.53943781 14.5810763,3.19812449"
    })), isIndeterminate && React.createElement("svg", {
      width: "10",
      height: "2",
      viewBox: "0 0 10 2",
      fill: "currentColor",
      xmlns: "http://www.w3.org/2000/svg"
    }, React.createElement("rect", {
      x: "0",
      y: "0",
      width: "10",
      height: "2"
    }))), React.createElement("span", {
      style: {
        color: textColor[functionalState]
      },
      className: styles.text
    }, children))
  );
};

Checkbox.propTypes = {
  /**
   * Disables the input and the label.
   */
  isDisabled: PropTypes.bool,

  /**
   * Determines if the checkbox is checked.
   */
  isChecked: PropTypes.bool,

  /**
   * Makes the radio and text color red.
   */
  hasError: PropTypes.bool,

  /**
   * Text or elements that appear within the label.
   */
  children: PropTypes.node,

  /**
   * The `id` is added to the checkbox as an HTML attribute and passed to the `onChange`
   * function.
   */
  id: PropTypes.string,

  /**
   * Checkboxes on a page with the same name will be grouped together when sent to the server.
   * The browser will only send the value of checkboxes that are checked.
   */
  name: PropTypes.string,

  /**
   * Determine that padding that gets applied to the label. This can be used
   * to increase the label's click target. The value supplied should be a
   * string with a unit such as `8px` or `8px 16px`.
   */
  labelPadding: PropTypes.string,

  /**
   * Function that runs when a checkbox value changes. It receives the new boolean value and
   * the provided `id` as such: `props.onChange(e.target.checked, props.id)`.
   */
  onChange: PropTypes.func.isRequired,

  /**
   * Shows a horizontal line to represent an indeterminate input.
   */
  isIndeterminate: PropTypes.bool,

  /**
   * A selector hook into the React component for use in automated testing environments. It is
   * applied internally to the `<input />` element.
   */
  dataTest: PropTypes.string
};
Checkbox.defaultProps = {
  isDisabled: false,
  children: null,
  id: null,
  isChecked: false,
  hasError: false,
  name: null,
  labelPadding: '14px 0',
  isIndeterminate: false,
  dataTest: undefined
};

exports.default = Checkbox;
//# sourceMappingURL=index.cjs.js.map
